@@ -2,14 +2,15 @@ import logging
 
 from loguru import logger
 
-# TODO: 1.0 remove windows folder and expose memory
 from .constants import *
-from .wad import Wad
-from .nif import NifMap
 from .errors import *
-from . import utils, windows, cli
-from .application import WizWalker
+from .utils import XYZ, Rectangle
+from . import cli, combat, memory, utils
+from .file_readers import CacheHandler, NifMap, Wad
+from .mouse_handler import MouseHandler
 from .client import Client
+from .application import WizWalker
+from .hotkey import *
 
 logger.disable("wizwalker")
 logging.getLogger("pymem").setLevel(logging.FATAL)
